@@ -134,7 +134,7 @@ class PixWindow(QMainWindow):  ######### Second Window Class ###########
     self.timer.timeout.connect(self.loadPix.start)
     self.parent = parent
     self.reader = QImageReader()
-    self.reader.setScaledSize(QSize(800,480))#self.width(),self.height()-100))
+    self.reader.setScaledSize(QSize(800*0.8,480*0.8))#self.width(),self.height()-100))
     self.destroyed.connect(self.delete)
     self.imageLabel = QLabel()
     self.scrollArea = QScrollArea()
@@ -234,23 +234,22 @@ class PixWindow(QMainWindow):  ######### Second Window Class ###########
     # ustawiamy scrollarea zeby obrazek maly byl na srodku ekranu
     # dzielimy wysokosc ekranu przez 2, nastepnie odejmujemy wysokosc
     # imagelabel
-#    self.imageLabel.setPixmap(self.imageLabel.pixmap().scaledToHeight(800))
-#    if self.parent.checkOrientation() == "portrait":
+    
     p = self.imageLabel.pixmap().scaledToWidth(self.width())
-#    else:
-#      p = QPixmap(self.imageLabel.pixmap().scaledToHeight(self.height()))
     self.imageLabel.resize(self.width(), p.height())
+    
     if p.height() < self.height():
-#      print p.height(), self.height()
       self.scrollArea.move(0, (self.height()/2)-(self.imageLabel.height()/2))
-#      print 0, (self.height()/2)-(self.imageLabel.height()/2)
     else:
-      self.scrollArea.move(0,0)
+      p = self.imageLabel.pixmap().scaledToHeight(self.height())
+      self.imageLabel.resize(p.width(), self.height())
+      self.scrollArea.move((self.width()/2)-(self.imageLabel.width()/2), 0)
       
   def minimalizePix(self):
     self.dbus.exit_app_view("MaePyGallery - minimalize")
     
   def nextPix(self):
+    self.blockSignals(True)  
     #    print dir(QThread)
     self.loadBetterFlag = 0
     if self.timer.isActive():
@@ -260,8 +259,12 @@ class PixWindow(QMainWindow):  ######### Second Window Class ###########
     else:
       self.index = self.index+1
       
-    self.reader.setFileName(self.licz[self.index])  
-    self.fitPix()
+    self.reader.setFileName(self.licz[self.index])
+    pixSize = self.reader.size()
+    pixSize.scale(800*0.8,480*0.8, Qt.KeepAspectRatio)
+    self.reader.setScaledSize(pixSize)
+    if self.flag == 1:  
+      self.fitPix()
     #w while wykonuje sie animacja :) zwykly move + procevent
     i=0
     temp = self.width()/6
@@ -273,10 +276,11 @@ class PixWindow(QMainWindow):  ######### Second Window Class ###########
       
     self.imageLabel.setPixmap(pix)
     self.fitPix()
-    self.setWindowTitle(str(self.licz[self.index]))    
-    
-    
+    self.setWindowTitle(str(self.licz[self.index]))
+    self.blockSignals(False)    
+        
   def prevPix(self):
+    self.blockSignals(True)
     self.loadBetterFlag = 0
     if self.timer.isActive():
       self.timer.stop()
@@ -286,7 +290,11 @@ class PixWindow(QMainWindow):  ######### Second Window Class ###########
       self.index = self.index-1
 
     self.reader.setFileName(self.licz[self.index])  
-    self.fitPix()
+    pixSize = self.reader.size()
+    pixSize.scale(800*0.8,480*0.8, Qt.KeepAspectRatio)
+    self.reader.setScaledSize(pixSize)
+    if self.flag == 1:
+      self.fitPix()
     i=0
     temp = self.width()/6
     pix = QPixmap(self.reader.read())
@@ -297,16 +305,17 @@ class PixWindow(QMainWindow):  ######### Second Window Class ###########
     self.imageLabel.setPixmap(pix)
     self.fitPix()
     self.setWindowTitle(str(self.licz[self.index]))
+    self.blockSignals(False)
 
   def mouseDoubleClickEvent(self, e):  #powiekszanie obrazka w nacisnietym miejscu
     if self.flag == 0:    
-      if self.imageLabel.height() < self.height(): #operowanie na podstawie wartosci scrollbara
+      if self.parent.checkOrientation() == "portrait": #self.imageLabel.height() < self.height(): #operowanie na podstawie wartosci scrollbara
         #skalowanie dla trybu portretowego
         p = QPixmap(self.imageLabel.pixmap()).scaledToHeight(800)
         self.imageLabel.resize(p.width(), p.height()-10)
         self.scrollArea.move(0,0)
         tempV = p.height()/2        
-        tempH = p.width()/2
+        tempH = e.x()
         self.scrollArea.verticalScrollBar().setValue(tempV)
         self.scrollArea.horizontalScrollBar().setValue(tempH)
         if self.loadBetterFlag == 0:
@@ -318,10 +327,15 @@ class PixWindow(QMainWindow):  ######### Second Window Class ###########
           self.loadBetterFlag = 1
         self.flag = 1
 #      self.scrollArea.move(0, (self.height()/2)-(self.imageLabel.height()/2))      
-      else: 
+      elif self.parent.checkOrientation() == "landscape": 
         #skalowanie dla trybu poziomego
         self.imageLabel.resize(self.imageLabel.width()*2,self.imageLabel.height()*2)
 #        self.imageLabel.pixmap().scaledToWidth(self.imageLabel.width()*2)
+#        if self.scrollArea.horizontalScrollBar().value() == 0 and self.scrollArea.verticalScrollBar().value() == 0:
+          #scrollbary sa == 0
+        self.scrollArea.horizontalScrollBar().setValue(e.x())
+        self.scrollArea.verticalScrollBar().setValue(e.y())
+        self.scrollArea.move(0,0)  
         if self.loadBetterFlag == 0:
           self.timer.start(1)
           box = QtMaemo5.QMaemo5InformationBox()
@@ -329,16 +343,13 @@ class PixWindow(QMainWindow):  ######### Second Window Class ###########
           box.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, 1)
           box.show()
           self.loadBetterFlag = 1
-        if self.scrollArea.horizontalScrollBar().value() == 0 and self.scrollArea.verticalScrollBar().value() == 0:
-          self.scrollArea.horizontalScrollBar().setValue(e.x())
-          self.scrollArea.verticalScrollBar().setValue(e.y())  
-        elif self.scrollArea.horizontalScrollBar().value() == 0:
-          self.scrollArea.horizontalScrollBar().setValue(e.x())
-        elif self.scrollArea.horizontalScrollBar().value() == 0:
-          self.scrollArea.horizontalScrollBar().setValue(e.y()) 
-        else:
-          self.scrollArea.horizontalScrollBar().setValue(self.scrollArea.horizontalScrollBar().value()*3)
-          self.scrollArea.verticalScrollBar().setValue(self.scrollArea.verticalScrollBar().value()*3)
+#        elif self.scrollArea.horizontalScrollBar().value() == 0:
+#          self.scrollArea.horizontalScrollBar().setValue(e.x())
+#        elif self.scrollArea.horizontalScrollBar().value() == 0:
+#          self.scrollArea.horizontalScrollBar().setValue(e.y()) 
+#        else:
+#          self.scrollArea.horizontalScrollBar().setValue(self.scrollArea.horizontalScrollBar().value()*3)
+#          self.scrollArea.verticalScrollBar().setValue(self.scrollArea.verticalScrollBar().value()*3)
       self.flag = 1    
     elif self.flag == 1:
       self.fitPix()
@@ -363,7 +374,6 @@ class Main(QMainWindow): ################## Main Class ##################
   def __init__(self, size, parent=None):
     super(Main, self).__init__()
     
-    print dir(QApplication)
     self.osso_c = osso.Context("maepygallery", "0.1.3", False)
     self.reader = QImageReader()
     self.setWindowTitle("MaePyGallery - " + self.dirPix)
@@ -387,9 +397,9 @@ class Main(QMainWindow): ################## Main Class ##################
     aboutDialog.setShortcut("Ctrl+A")
     aboutDialog.triggered.connect(self.aboutDialog)
   
-    chDirAct = QAction("&Change directory", self)
-    chDirAct.setShortcut("Ctrl+D")
-    chDirAct.triggered.connect(self.chPixDir)
+    self.chDirAct = QAction("&Change directory", self)
+    self.chDirAct.setShortcut("Ctrl+D")
+    self.chDirAct.triggered.connect(self.chPixDir)
     
     exitAct = QAction("&Exit",self)
     exitAct.setShortcut("Ctrl+Q")
@@ -409,7 +419,7 @@ class Main(QMainWindow): ################## Main Class ##################
     
     self.menubar = self.menuBar()
     self.fileMenu = self.menubar.addMenu("&File")
-    self.fileMenu.addAction(chDirAct)
+    self.fileMenu.addAction(self.chDirAct)
     self.fileMenu.addAction(helpDialog)
     self.fileMenu.addAction(self.refreshAct)
     self.fileMenu.addAction(aboutDialog)
@@ -484,6 +494,7 @@ class Main(QMainWindow): ################## Main Class ##################
       
     self.refreshAct.setDisabled(True)
     self.deleteAct.setDisabled(True)
+    self.chDirAct.setDisabled(True)
     self.layoutLandscape = QGridLayout(self.label)
     self.layoutPortrait = QGridLayout(self.labelP)
     self.miniatures = range(len(self.miniaturki))#len(self.licz))
@@ -587,7 +598,8 @@ class Main(QMainWindow): ################## Main Class ##################
     #przesuwanie okna na koniec
     self.scrollArea.verticalScrollBar().setValue(self.adjustedHeight)      
     self.refreshAct.setDisabled(False)
-    self.deleteAct.setDisabled(False)    
+    self.deleteAct.setDisabled(False)
+    self.chDirAct.setDisabled(False)    
     os.chdir(self.dirPix)
     self.orientationChanged()
     
@@ -598,6 +610,9 @@ class Main(QMainWindow): ################## Main Class ##################
     self.pix.setStyleSheet("QToolButton { background-color: rgba(0,0,0,0%); }")
     self.pix.setWindowTitle(str(self.licz[index]))
     self.pix.reader.setFileName(self.licz[index])#self.sender().path)
+    pixSize = self.pix.reader.size()
+    pixSize.scale(800*0.8,480*0.8, Qt.KeepAspectRatio)
+    self.pix.reader.setScaledSize(pixSize)
     bla = QPixmap(self.pix.reader.read())
     if bla.isNull():
       print "error while loading pixmap"
@@ -656,7 +671,19 @@ class Main(QMainWindow): ################## Main Class ##################
 #      self.loadingLabela.hide()
       
   def helpDialog(self):
-    text = "Interface of second window: <br> Left border button - previous picture <br> Right border button - next picture <br> Upper border button - restore view <br> Bottom border button - minimalize window"
+    text = """Interface of second window: <br> Left border button - previous picture <br> 
+    Right border button - next picture <br> 
+    Upper border button - restore view <br>
+    Bottom border button - minimalize window <br>
+    DoublePress - zoom in <br>
+    Keys:<br>
+      Z - zoom in<br>
+      X - zoom out<br>
+      C - fit picture size to screen size<br>
+      Space - next picture<br>
+      M - previous picture<br>
+      Q - Quit
+    """
     temp = QMessageBox.information(self, "Help", text)
       
   def chPixDir(self):
